summaryrefslogtreecommitdiffstats
path: root/drivers/staging/telephony
diff options
context:
space:
mode:
authorAdam Buchbinder <adam.buchbinder@gmail.com>2012-09-19 21:51:08 -0400
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2012-09-21 08:56:41 -0700
commitbff6c3e00ca7e56ca82e19ffb722159cf1216d20 (patch)
tree911a9ce150f4917113cf1c17ac499581e1886199 /drivers/staging/telephony
parentf2635894e8e786d7c93a21f24efb690981d15842 (diff)
downloadlinux-bff6c3e00ca7e56ca82e19ffb722159cf1216d20.tar.bz2
staging: Fix spelling of "asynchronous" in comments.
"Asychronous" is misspelled in some comments. No code changes. Signed-off-by: Adam Buchbinder <adam.buchbinder@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/telephony')
-rw-r--r--drivers/staging/telephony/ixj.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/telephony/ixj.c b/drivers/staging/telephony/ixj.c
index b303c9192e17..1cfa0b07d725 100644
--- a/drivers/staging/telephony/ixj.c
+++ b/drivers/staging/telephony/ixj.c
@@ -7057,7 +7057,7 @@ static int ixj_selfprobe(IXJ *j)
printk(KERN_INFO "Enable Line Monitor\n");
if (ixjdebug & 0x0002)
- printk(KERN_INFO "Set Line Monitor to Asyncronous Mode\n");
+ printk(KERN_INFO "Set Line Monitor to Asynchronous Mode\n");
if (ixj_WriteDSPCommand(0x7E01, j)) /* Asynchronous Line Monitor */
return -1;
@@ -7068,7 +7068,7 @@ static int ixj_selfprobe(IXJ *j)
if (ixj_WriteDSPCommand(0x5151, j)) /* Enable DTMF detection */
return -1;
- if (ixj_WriteDSPCommand(0x6E01, j)) /* Set Asyncronous Tone Generation */
+ if (ixj_WriteDSPCommand(0x6E01, j)) /* Set Asynchronous Tone Generation */
return -1;
set_rec_depth(j, 2); /* Set Record Channel Limit to 2 frames */